==> haskell-configurator-0.3.0.0-354-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator
version:              0.3.0.0
visibility:           public
id:                   configurator-0.3.0.0-BrfomgxXwze43o7eNPPLbj
key:                  configurator-0.3.0.0-BrfomgxXwze43o7eNPPLbj
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan

maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/bos/configurator
synopsis:             Configuration management
description:
    A configuration management library for programs and daemons.

    Features include:

    * Automatic, dynamic reloading in response to modifications to
    configuration files.

    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).

    * Subscription-based notification of changes to configuration
    properties.

    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.

    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.

category:             Configuration, Data
abi:                  2dde1846cc776221599d8632967f67a9
exposed:              True
exposed-modules:      Data.Configurator Data.Configurator.Types
hidden-modules:
    Data.Configurator.Instances Data.Configurator.Parser
    Data.Configurator.Types.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/configurator-0.3.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator
hs-libraries:         HSconfigurator-0.3.0.0-BrfomgxXwze43o7eNPPLbj
depends:
    attoparsec-0.14.4-4fjJnHqpy2x7zsjAU0XRWO base-4.15.1.0
    bytestring-0.10.12.1 directory-1.3.6.2
    hashable-1.4.2.0-8JSq7I7AhyyZ2Q90BxZWW text-1.2.5.0
    unix-compat-0.7-ImZLGak9HFVAcx5hoGYQVF
    unordered-containers-0.2.19.1-Km0aDxhChoIJJSbiufyazz

haddock-interfaces:
    /usr/share/doc/haskell-configurator/html/configurator.haddock

haddock-html:         /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-0.3.0.0-396-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator
version:              0.3.0.0
visibility:           public
id:                   configurator-0.3.0.0-6kmWHBdXBGb6VJe6kAsxQ3
key:                  configurator-0.3.0.0-6kmWHBdXBGb6VJe6kAsxQ3
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan

maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/bos/configurator
synopsis:             Configuration management
description:
    A configuration management library for programs and daemons.

    Features include:

    * Automatic, dynamic reloading in response to modifications to
    configuration files.

    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).

    * Subscription-based notification of changes to configuration
    properties.

    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.

    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.

category:             Configuration, Data
abi:                  315389cbae677b29721778c0c14df06d
exposed:              True
exposed-modules:      Data.Configurator Data.Configurator.Types
hidden-modules:
    Data.Configurator.Instances Data.Configurator.Parser
    Data.Configurator.Types.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/configurator-0.3.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator
hs-libraries:         HSconfigurator-0.3.0.0-6kmWHBdXBGb6VJe6kAsxQ3
depends:
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    bytestring-0.11.4.0 directory-1.3.6.2
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt text-1.2.5.0
    unix-compat-0.7.1-Gd0rWWXZiTLChOv5moYxd8
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox

haddock-interfaces:
    /usr/share/doc/haskell-configurator/html/configurator.haddock

haddock-html:         /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
